You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beehive.apache.org by cs...@apache.org on 2006/03/17 22:18:27 UTC

svn commit: r386715 - in /beehive/trunk/system-controls: src/webservice/control/org/apache/beehive/controls/system/webservice/generator/ src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/ test/webservice/ test/webservice/weba...

Author: cschoett
Date: Fri Mar 17 13:18:24 2006
New Revision: 386715

URL: http://svn.apache.org/viewcvs?rev=386715&view=rev
Log:
Some minor clean, added ability for wsc generator to gen from a wsdl url as well as a wsdl file.

Modified:
    beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/GeneratorUtils.java
    beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/WebServiceControlGenerator.java
    beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/WebServiceControlGeneratorTask.java
    beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisCall.java
    beehive/trunk/system-controls/test/webservice/build.xml
    beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerDocLitWrapped.wsdl
    beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerRpcEnc.wsdl
    beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerRpcLit.wsdl
    beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartDocLitWrapped.wsdl
    beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartRpcEnc.wsdl
    beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartRpcLit.wsdl

Modified: beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/GeneratorUtils.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/GeneratorUtils.java?rev=386715&r1=386714&r2=386715&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/WebServiceControlGenerator.java (original)
+++ beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/WebServiceControlGenerator.java Fri Mar 17 13:18:24 2006
@@ -15,23 +15,12 @@
  */
 package org.apache.beehive.controls.system.webservice.generator;
 
-import javax.xml.namespace.QName;
-import java.io.File;
-import java.io.FileFilter;
-import java.io.FileNotFoundException;
-import java.io.PrintWriter;
-import java.io.UnsupportedEncodingException;
-import java.io.Writer;
-import java.lang.reflect.Array;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Properties;
+import org.apache.beehive.controls.system.webservice.ServiceControl;
+import org.apache.beehive.controls.system.webservice.jaxrpc.ClientBindingLookupFactory;
 import org.apache.beehive.controls.system.webservice.wsdl.Wsdl;
 import org.apache.beehive.controls.system.webservice.wsdl.WsdlOpParameter;
 import org.apache.beehive.controls.system.webservice.wsdl.WsdlOpReturnType;
 import org.apache.beehive.controls.system.webservice.wsdl.WsdlOperation;
-import org.apache.beehive.controls.system.webservice.jaxrpc.ClientBindingLookupFactory;
-import org.apache.beehive.controls.system.webservice.ServiceControl;
 import org.apache.beehive.webservice.utils.JavaClassUtils;
 import org.apache.beehive.webservice.utils.databinding.BindingLookupStrategy;
 import org.apache.velocity.Template;
@@ -42,6 +31,20 @@
 import org.apache.velocity.exception.ResourceNotFoundException;
 import org.apache.velocity.runtime.resource.loader.ClasspathResourceLoader;
 
+import javax.xml.namespace.QName;
+import java.io.File;
+import java.io.FileFilter;
+import java.io.FileNotFoundException;
+import java.io.PrintWriter;
+import java.io.UnsupportedEncodingException;
+import java.io.Writer;
+import java.lang.reflect.Array;
+import java.net.URI;
+import java.net.URL;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Properties;
+
 /**
  * Generate a service control from a WSDL using Velocity.
  */
@@ -60,11 +63,11 @@
      * Ant task / general entry point. Generate a service control for each WSDL found
      * in the wsdlDirectory.
      *
-     * @param wsdlDirectory      Directory of WSDLs to process.
-     * @param pkgName            Package name of generated controls. If null, package name will be generated
-     *                           from the WSDL's target namespace.
-     * @param wsdlRuntimePath   WSDL path annotation value for generated controls.
-     * @param copyWsdl          Copy the wsdl to the web service control destination directory.
+     * @param wsdlDirectory   Directory of WSDLs to process.
+     * @param pkgName         Package name of generated controls. If null, package name will be generated
+     *                        from the WSDL's target namespace.
+     * @param wsdlRuntimePath WSDL path annotation value for generated controls.
+     * @param copyWsdl        Copy the wsdl to the web service control destination directory.
      * @throws Exception
      */
     static void generateJCXs(File wsdlDirectory, File outputDir, String pkgName,
@@ -79,23 +82,70 @@
     /**
      * Ant task / general entry point. Generate a service control for the specified WSDL file.
      *
-     * @param wsdlFile           A WSDL file.
-     * @param pkgName            Package name of generated controls. If null, package name will be generated
-     *                           from the WSDL's target namespace.
+     * @param wsdlFile        A WSDL file.
+     * @param pkgName         Package name of generated controls. If null, package name will be generated
+     *                        from the WSDL's target namespace.
      * @param wsdlRuntimePath WSDL path annotation value for generated control.
-     * @param copyWsdl          Copy the wsdl to the web service control destination directory.
-     * @param serviceQName        Name of the service to generate the control.
-     * @param servicePortName     Name of the service port used to generate the control.
+     * @param copyWsdl        Copy the wsdl to the web service control destination directory.
+     * @param serviceQName    Name of the service to generate the control.
+     * @param servicePortName Name of the service port used to generate the control.
      * @throws Exception
      */
     static void generateJCX(File wsdlFile, File outputDir, String pkgName,
                             String wsdlRuntimePath, boolean copyWsdl,
-                            QName serviceQName,  String servicePortName) throws Exception {
+                            QName serviceQName, String servicePortName) throws Exception {
 
         assert wsdlFile.isFile() : "wsdlFile must be a file!";
+        genWsc(wsdlFile.toURI(), wsdlFile.getName(), outputDir, pkgName,
+               wsdlRuntimePath, copyWsdl, serviceQName, servicePortName);
+    }
+
+    /**
+     * Ant task / general entry point. Generate a service control for the specified WSDL file.
+     *
+     * @param wsdlURL         A URL to a WSDL.
+     * @param pkgName         Package name of generated controls. If null, package name will be generated
+     *                        from the WSDL's target namespace.
+     * @param wsdlRuntimePath WSDL path annotation value for generated control.
+     * @param copyWsdl        Copy the wsdl to the web service control destination directory.
+     * @param serviceQName    Name of the service to generate the control.
+     * @param servicePortName Name of the service port used to generate the control.
+     * @throws Exception
+     */
+    static void generateWSC(URL wsdlURL, File outputDir, String pkgName,
+                            String wsdlRuntimePath, boolean copyWsdl,
+                            QName serviceQName, String servicePortName) throws Exception {
+
+        String wsdlFileName = GeneratorUtils.genWsdlFileNameFromURL(wsdlURL);
+        System.out.println(wsdlFileName);
+        genWsc(wsdlURL.toURI(), wsdlFileName, outputDir, pkgName,
+               wsdlRuntimePath, copyWsdl, serviceQName, servicePortName);
+    }
+
+
+    /* ------------------------------------------------------------------------------------------- */
+    /*                               Private Methods                                               */
+    /* ------------------------------------------------------------------------------------------- */
+
+    /**
+     * Do the work to gen the wsc.
+     *
+     * @param wsdlURI URI of the wsdl file.
+     * @param wsdlFileName The name of the Wsdl file (if copy wsdl flag set)
+     * @param outputDir Directory to create the wsc in.
+     * @param pkgName Java package name for the WSC.
+     * @param wsdlRuntimePath Runtime path for wsdl.
+     * @param copyWsdl Copy wsdl to wsc generated location?
+     * @param serviceQName Service QName.
+     * @param servicePortName Service port name.
+     * @throws Exception On error.
+     */
+    private static void genWsc(URI wsdlURI, String wsdlFileName, File outputDir, String pkgName,
+                               String wsdlRuntimePath, boolean copyWsdl,
+                               QName serviceQName, String servicePortName) throws Exception {
 
         // load and parse the WSDL file
-        Wsdl wsdl = new Wsdl(wsdlFile.toURI(), serviceQName, servicePortName);
+        Wsdl wsdl = new Wsdl(wsdlURI, serviceQName, servicePortName);
         if (pkgName == null) {
             pkgName = GeneratorUtils.generatePackageName(wsdl.getTargetNamespace());
         }
@@ -110,24 +160,24 @@
         if (wsdlRuntimePath != null) {
             wsdlRuntimePath = wsdlRuntimePath.replace('\\', '/');
             if (wsdlRuntimePath.endsWith("/")) {
-                wsdlPath = wsdlRuntimePath + wsdlFile.getName();
+                wsdlPath = wsdlRuntimePath + wsdlFileName;
             }
             else {
-                wsdlPath = wsdlRuntimePath + '/' + wsdlFile.getName();
+                wsdlPath = wsdlRuntimePath + '/' + wsdlFileName;
             }
         }
         else if (copyWsdl) {
             String dirName = GeneratorUtils.packageNameToDirectoryName(pkgName);
             dirName = dirName.replace('\\', '/');
             if (dirName.endsWith("/")) {
-                wsdlPath =  dirName + wsdlFile.getName();
+                wsdlPath = dirName + wsdlFileName;
             }
             else {
-                wsdlPath = dirName + '/' + wsdlFile.getName();
+                wsdlPath = dirName + '/' + wsdlFileName;
             }
         }
         else {
-            wsdlPath = wsdlFile.toURL().toString();
+            wsdlPath = wsdlURI.toString();
         }
 
         List<MethodInfo> methodList = buildMethodList(wsdl);
@@ -162,19 +212,15 @@
                 wsdlPath = GeneratorUtils.packageNameToDirectoryName(pkgName);
                 wsdlPath = wsdlPath.replace('\\', '/');
                 if (!wsdlPath.endsWith("/")) {
-                        wsdlPath += '/';
+                    wsdlPath += '/';
                 }
-                wsdlPath += wsdlFile.getName();
+                wsdlPath += wsdlFileName;
             }
             File wsdlCopy = new File(outputDir, wsdlPath);
-            GeneratorUtils.copyFile(wsdlFile, wsdlCopy);
+            GeneratorUtils.copyFile(wsdlURI.toURL(), wsdlCopy);
         }
     }
 
-    /* ------------------------------------------------------------------------------------------- */
-    /*                               Private Methods                                               */
-    /* ------------------------------------------------------------------------------------------- */
-
     /**
      * Initialize the velocity engine.
      *
@@ -270,9 +316,10 @@
 
     /**
      * Find the class for the xmlType.
-     * @param xmlType XmlType to map to java class.
+     *
+     * @param xmlType     XmlType to map to java class.
      * @param itemXmlType If xmlType is an array type, itemXmlType specifies the component type of the array.
-     * @param isArray is xmlType an array type?
+     * @param isArray     is xmlType an array type?
      * @return The class which the xmlType maps to. void.class if xmlType is null.
      */
     static private Class getClass(QName xmlType, QName itemXmlType, boolean isArray) {

Modified: beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/WebServiceControlGeneratorTask.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/WebServiceControlGeneratorTask.java?rev=386715&r1=386714&r2=386715&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/WebServiceControlGeneratorTask.java (original)
+++ beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/WebServiceControlGeneratorTask.java Fri Mar 17 13:18:24 2006
@@ -23,6 +23,8 @@
 
 import javax.xml.namespace.QName;
 import java.io.File;
+import java.net.URL;
+import java.net.MalformedURLException;
 
 /**
  * The web service control generator Ant task generates a web service control from a WSDL.
@@ -54,6 +56,7 @@
     private File _srcfile;
     private File _srcdir;
     private File _destdir;
+    private URL _srcURL;
 
     private String _destPackageName;
     private String _wsdlRuntimePath;
@@ -156,6 +159,19 @@
     }
 
     /**
+     * Set the source url to get the WSDL file from.
+     * @param urlStr
+     */
+    public void setSrcUrl(String urlStr) {
+        try {
+            _srcURL = new URL(urlStr);
+        }
+        catch (MalformedURLException e) {
+            throw new BuildException("Invalid srcUrl parameter!", e);
+        }
+    }
+
+    /**
      * A web service control needs to be able to locate the WSDL it was generated from at runtime. This value may be
      * in the form of a URL or fully qualified location within the classpath of the application at runtime.  It is
      * not necessary to include the name of the WSDL, just its path information.
@@ -187,7 +203,12 @@
         }
 
         try {
-            if (_srcfile != null) {
+            if (_srcURL != null) {
+                WebServiceControlGenerator.generateWSC(_srcURL, _destdir, _destPackageName,
+                                                       _wsdlRuntimePath, _copyWsdl, serviceQName,
+                                                       _servicePortName);
+            }
+            else if (_srcfile != null) {
                 WebServiceControlGenerator.generateJCX(_srcfile, _destdir, _destPackageName,
                                                        _wsdlRuntimePath, _copyWsdl, serviceQName,
                                                        _servicePortName);
@@ -212,8 +233,8 @@
      */
     private void validateAttributeSettings() {
 
-        if (_srcfile == null && _srcdir == null) {
-            throw new BuildException("The srcFile or srcDir attribute must be set");
+        if (_srcfile == null && _srcdir == null && _srcURL == null) {
+            throw new BuildException("The srcFile, srcDir or srcUrl attribute must be set");
         }
 
         if (_srcfile != null && _srcdir != null) {
@@ -224,8 +245,8 @@
             throw new BuildException("The srcFile must be a file");
         }
 
-        if (_srcfile == null && _serviceName != null) {
-            throw new BuildException("The serviceName attribute can only be used with the srcFile attribute");
+        if (_srcfile == null && _srcURL == null && _serviceName != null) {
+            throw new BuildException("The serviceName attribute can only be used with the srcFile or srcUrl attributes");
         }
 
         if (_srcdir != null && !_srcdir.isDirectory()) {

Modified: beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisCall.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisCall.java?rev=386715&r1=386714&r2=386715&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisCall.java (original)
+++ beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisCall.java Fri Mar 17 13:18:24 2006
@@ -33,7 +33,7 @@
 import org.apache.beehive.webservice.utils.databinding.BindingLookupStrategy;
 
 /**
- * This is the AXIS 1.2 implementation of the call abstraction layer of the service control.
+ * The AXIS 1.x implementation of the call abstraction layer of the service control.
  */
 public final class AxisCall
     extends GenericCall {

Modified: beehive/trunk/system-controls/test/webservice/build.xml
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/build.xml?rev=386715&r1=386714&r2=386715&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/build.xml (original)
+++ beehive/trunk/system-controls/test/webservice/build.xml Fri Mar 17 13:18:24 2006
@@ -122,6 +122,14 @@
         <echo message="--------------------------------------------------"/>
     </target>
 
+    <target name="generate_debug">
+        <taskdef name="webservice-control-gen"
+                 classname="org.apache.beehive.controls.system.webservice.generator.WebServiceControlGeneratorTask"
+                 classpathref="client.classpath"/>
+        <webservice-control-gen srcUrl="http://www.ignyte.com/webservices/ignyte.whatsshowing.webservice/moviefunctions.asmx?wsdl" 
+                                copyWsdl="true" destdir="/tmp/wsdls_out" destPackageName="foo"/>
+    </target>
+
     <target name="test.server" description="Run the WSC server tests">
         <echo message="--------------------------------------------------"/>
         <echo message="|     Start WSC Server tests                     |"/>
@@ -142,7 +150,7 @@
                 <antcall target="ensure.deployed"/>
 
                 <!-- Validate the wsdls we have against those returned from WSM, fail if any diffs -->
-<!--                <antcall target="check-wsdls"/> -->
+                <antcall target="check-wsdls"/>
 
                 <!-- wsdls have been validated and we are good to go - build the services controls -->
                 <antcall target="build.client"/>

Modified: beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerDocLitWrapped.wsdl
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerDocLitWrapped.wsdl?rev=386715&r1=386714&r2=386715&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerDocLitWrapped.wsdl (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerDocLitWrapped.wsdl Fri Mar 17 13:18:24 2006
@@ -5,54 +5,54 @@
  <wsdl:types>
   <schema elementFormDefault="qualified" targetNamespace="http://datahandler.attachments" xmlns="http://www.w3.org/2001/XMLSchema">
    <import namespace="http://xml.apache.org/xml-soap"/>
-   <element name="getJpgImage">
+   <element name="getPlainText">
     <complexType/>
    </element>
-   <element name="getJpgImageResponse">
+   <element name="getPlainTextResponse">
     <complexType>
      <sequence>
       <element name="return" type="apachesoap:DataHandler"/>
      </sequence>
     </complexType>
    </element>
-   <element name="getGifImage">
-    <complexType/>
-   </element>
-   <element name="getGifImageResponse">
+   <element name="echoPlainText">
     <complexType>
      <sequence>
-      <element name="return" type="apachesoap:DataHandler"/>
+      <element name="pt" type="apachesoap:DataHandler"/>
      </sequence>
     </complexType>
    </element>
-   <element name="getPlainText">
-    <complexType/>
-   </element>
-   <element name="getPlainTextResponse">
+   <element name="echoPlainTextResponse">
     <complexType>
      <sequence>
       <element name="return" type="apachesoap:DataHandler"/>
      </sequence>
     </complexType>
    </element>
-   <element name="echoPlainText">
+   <element name="getXmlText">
+    <complexType/>
+   </element>
+   <element name="getXmlTextResponse">
     <complexType>
      <sequence>
-      <element name="pt" type="apachesoap:DataHandler"/>
+      <element name="return" type="apachesoap:DataHandler"/>
      </sequence>
     </complexType>
    </element>
-   <element name="echoPlainTextResponse">
+   <element name="getJpgImage">
+    <complexType/>
+   </element>
+   <element name="getJpgImageResponse">
     <complexType>
      <sequence>
       <element name="return" type="apachesoap:DataHandler"/>
      </sequence>
     </complexType>
    </element>
-   <element name="getXmlText">
+   <element name="getGifImage">
     <complexType/>
    </element>
-   <element name="getXmlTextResponse">
+   <element name="getGifImageResponse">
     <complexType>
      <sequence>
       <element name="return" type="apachesoap:DataHandler"/>
@@ -86,21 +86,15 @@
 
    </wsdl:message>
 
-   <wsdl:message name="getXmlTextRequest">
-
-      <wsdl:part element="impl:getXmlText" name="parameters"/>
-
-   </wsdl:message>
-
    <wsdl:message name="getJpgImageRequest">
 
       <wsdl:part element="impl:getJpgImage" name="parameters"/>
 
    </wsdl:message>
 
-   <wsdl:message name="getXmlTextResponse">
+   <wsdl:message name="getXmlTextRequest">
 
-      <wsdl:part element="impl:getXmlTextResponse" name="parameters"/>
+      <wsdl:part element="impl:getXmlText" name="parameters"/>
 
    </wsdl:message>
 
@@ -110,6 +104,12 @@
 
    </wsdl:message>
 
+   <wsdl:message name="getXmlTextResponse">
+
+      <wsdl:part element="impl:getXmlTextResponse" name="parameters"/>
+
+   </wsdl:message>
+
    <wsdl:message name="echoPlainTextResponse">
 
       <wsdl:part element="impl:echoPlainTextResponse" name="parameters"/>
@@ -124,43 +124,43 @@
 
    <wsdl:portType name="DataHandlerDocLitWrapped">
 
-      <wsdl:operation name="getJpgImage">
+      <wsdl:operation name="getPlainText">
 
-         <wsdl:input message="impl:getJpgImageRequest" name="getJpgImageRequest"/>
+         <wsdl:input message="impl:getPlainTextRequest" name="getPlainTextRequest"/>
 
-         <wsdl:output message="impl:getJpgImageResponse" name="getJpgImageResponse"/>
+         <wsdl:output message="impl:getPlainTextResponse" name="getPlainTextResponse"/>
 
       </wsdl:operation>
 
-      <wsdl:operation name="getGifImage">
+      <wsdl:operation name="echoPlainText">
 
-         <wsdl:input message="impl:getGifImageRequest" name="getGifImageRequest"/>
+         <wsdl:input message="impl:echoPlainTextRequest" name="echoPlainTextRequest"/>
 
-         <wsdl:output message="impl:getGifImageResponse" name="getGifImageResponse"/>
+         <wsdl:output message="impl:echoPlainTextResponse" name="echoPlainTextResponse"/>
 
       </wsdl:operation>
 
-      <wsdl:operation name="getPlainText">
+      <wsdl:operation name="getXmlText">
 
-         <wsdl:input message="impl:getPlainTextRequest" name="getPlainTextRequest"/>
+         <wsdl:input message="impl:getXmlTextRequest" name="getXmlTextRequest"/>
 
-         <wsdl:output message="impl:getPlainTextResponse" name="getPlainTextResponse"/>
+         <wsdl:output message="impl:getXmlTextResponse" name="getXmlTextResponse"/>
 
       </wsdl:operation>
 
-      <wsdl:operation name="echoPlainText">
+      <wsdl:operation name="getJpgImage">
 
-         <wsdl:input message="impl:echoPlainTextRequest" name="echoPlainTextRequest"/>
+         <wsdl:input message="impl:getJpgImageRequest" name="getJpgImageRequest"/>
 
-         <wsdl:output message="impl:echoPlainTextResponse" name="echoPlainTextResponse"/>
+         <wsdl:output message="impl:getJpgImageResponse" name="getJpgImageResponse"/>
 
       </wsdl:operation>
 
-      <wsdl:operation name="getXmlText">
+      <wsdl:operation name="getGifImage">
 
-         <wsdl:input message="impl:getXmlTextRequest" name="getXmlTextRequest"/>
+         <wsdl:input message="impl:getGifImageRequest" name="getGifImageRequest"/>
 
-         <wsdl:output message="impl:getXmlTextResponse" name="getXmlTextResponse"/>
+         <wsdl:output message="impl:getGifImageResponse" name="getGifImageResponse"/>
 
       </wsdl:operation>
 
@@ -170,17 +170,17 @@
 
       <wsdlsoap:binding style="document" transport="http://schemas.xmlsoap.org/soap/http"/>
 
-      <wsdl:operation name="getJpgImage">
+      <wsdl:operation name="getPlainText">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getJpgImageRequest">
+         <wsdl:input name="getPlainTextRequest">
 
             <wsdlsoap:body use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getJpgImageResponse">
+         <wsdl:output name="getPlainTextResponse">
 
             <wsdlsoap:body use="literal"/>
 
@@ -188,17 +188,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="getGifImage">
+      <wsdl:operation name="echoPlainText">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getGifImageRequest">
+         <wsdl:input name="echoPlainTextRequest">
 
             <wsdlsoap:body use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getGifImageResponse">
+         <wsdl:output name="echoPlainTextResponse">
 
             <wsdlsoap:body use="literal"/>
 
@@ -206,17 +206,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="getPlainText">
+      <wsdl:operation name="getXmlText">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getPlainTextRequest">
+         <wsdl:input name="getXmlTextRequest">
 
             <wsdlsoap:body use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getPlainTextResponse">
+         <wsdl:output name="getXmlTextResponse">
 
             <wsdlsoap:body use="literal"/>
 
@@ -224,17 +224,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="echoPlainText">
+      <wsdl:operation name="getJpgImage">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="echoPlainTextRequest">
+         <wsdl:input name="getJpgImageRequest">
 
             <wsdlsoap:body use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="echoPlainTextResponse">
+         <wsdl:output name="getJpgImageResponse">
 
             <wsdlsoap:body use="literal"/>
 
@@ -242,17 +242,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="getXmlText">
+      <wsdl:operation name="getGifImage">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getXmlTextRequest">
+         <wsdl:input name="getGifImageRequest">
 
             <wsdlsoap:body use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getXmlTextResponse">
+         <wsdl:output name="getGifImageResponse">
 
             <wsdlsoap:body use="literal"/>
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerRpcEnc.wsdl
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerRpcEnc.wsdl?rev=386715&r1=386714&r2=386715&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerRpcEnc.wsdl (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerRpcEnc.wsdl Fri Mar 17 13:18:24 2006
@@ -19,21 +19,21 @@
 
    </wsdl:message>
 
-   <wsdl:message name="getXmlTextRequest">
+   <wsdl:message name="getJpgImageRequest">
 
    </wsdl:message>
 
-   <wsdl:message name="getJpgImageRequest">
+   <wsdl:message name="getXmlTextRequest">
 
    </wsdl:message>
 
-   <wsdl:message name="getXmlTextResponse">
+   <wsdl:message name="getJpgImageResponse">
 
       <wsdl:part name="return" type="apachesoap:DataHandler"/>
 
    </wsdl:message>
 
-   <wsdl:message name="getJpgImageResponse">
+   <wsdl:message name="getXmlTextResponse">
 
       <wsdl:part name="return" type="apachesoap:DataHandler"/>
 
@@ -45,35 +45,35 @@
 
    <wsdl:portType name="DataHandlerRpcEnc">
 
-      <wsdl:operation name="getJpgImage">
+      <wsdl:operation name="getPlainText">
 
-         <wsdl:input message="impl:getJpgImageRequest" name="getJpgImageRequest"/>
+         <wsdl:input message="impl:getPlainTextRequest" name="getPlainTextRequest"/>
 
-         <wsdl:output message="impl:getJpgImageResponse" name="getJpgImageResponse"/>
+         <wsdl:output message="impl:getPlainTextResponse" name="getPlainTextResponse"/>
 
       </wsdl:operation>
 
-      <wsdl:operation name="getGifImage">
+      <wsdl:operation name="getXmlText">
 
-         <wsdl:input message="impl:getGifImageRequest" name="getGifImageRequest"/>
+         <wsdl:input message="impl:getXmlTextRequest" name="getXmlTextRequest"/>
 
-         <wsdl:output message="impl:getGifImageResponse" name="getGifImageResponse"/>
+         <wsdl:output message="impl:getXmlTextResponse" name="getXmlTextResponse"/>
 
       </wsdl:operation>
 
-      <wsdl:operation name="getPlainText">
+      <wsdl:operation name="getJpgImage">
 
-         <wsdl:input message="impl:getPlainTextRequest" name="getPlainTextRequest"/>
+         <wsdl:input message="impl:getJpgImageRequest" name="getJpgImageRequest"/>
 
-         <wsdl:output message="impl:getPlainTextResponse" name="getPlainTextResponse"/>
+         <wsdl:output message="impl:getJpgImageResponse" name="getJpgImageResponse"/>
 
       </wsdl:operation>
 
-      <wsdl:operation name="getXmlText">
+      <wsdl:operation name="getGifImage">
 
-         <wsdl:input message="impl:getXmlTextRequest" name="getXmlTextRequest"/>
+         <wsdl:input message="impl:getGifImageRequest" name="getGifImageRequest"/>
 
-         <wsdl:output message="impl:getXmlTextResponse" name="getXmlTextResponse"/>
+         <wsdl:output message="impl:getGifImageResponse" name="getGifImageResponse"/>
 
       </wsdl:operation>
 
@@ -83,17 +83,17 @@
 
       <wsdlsoap:binding style="rpc" transport="http://schemas.xmlsoap.org/soap/http"/>
 
-      <wsdl:operation name="getJpgImage">
+      <wsdl:operation name="getPlainText">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getJpgImageRequest">
+         <wsdl:input name="getPlainTextRequest">
 
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://datahandler.attachments" use="encoded"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getJpgImageResponse">
+         <wsdl:output name="getPlainTextResponse">
 
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://datahandler.attachments" use="encoded"/>
 
@@ -101,17 +101,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="getGifImage">
+      <wsdl:operation name="getXmlText">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getGifImageRequest">
+         <wsdl:input name="getXmlTextRequest">
 
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://datahandler.attachments" use="encoded"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getGifImageResponse">
+         <wsdl:output name="getXmlTextResponse">
 
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://datahandler.attachments" use="encoded"/>
 
@@ -119,17 +119,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="getPlainText">
+      <wsdl:operation name="getJpgImage">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getPlainTextRequest">
+         <wsdl:input name="getJpgImageRequest">
 
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://datahandler.attachments" use="encoded"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getPlainTextResponse">
+         <wsdl:output name="getJpgImageResponse">
 
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://datahandler.attachments" use="encoded"/>
 
@@ -137,17 +137,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="getXmlText">
+      <wsdl:operation name="getGifImage">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getXmlTextRequest">
+         <wsdl:input name="getGifImageRequest">
 
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://datahandler.attachments" use="encoded"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getXmlTextResponse">
+         <wsdl:output name="getGifImageResponse">
 
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://datahandler.attachments" use="encoded"/>
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerRpcLit.wsdl
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerRpcLit.wsdl?rev=386715&r1=386714&r2=386715&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerRpcLit.wsdl (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/DataHandlerRpcLit.wsdl Fri Mar 17 13:18:24 2006
@@ -19,21 +19,21 @@
 
    </wsdl:message>
 
-   <wsdl:message name="getXmlTextRequest">
+   <wsdl:message name="getJpgImageRequest">
 
    </wsdl:message>
 
-   <wsdl:message name="getJpgImageRequest">
+   <wsdl:message name="getXmlTextRequest">
 
    </wsdl:message>
 
-   <wsdl:message name="getXmlTextResponse">
+   <wsdl:message name="getJpgImageResponse">
 
       <wsdl:part name="return" type="apachesoap:DataHandler"/>
 
    </wsdl:message>
 
-   <wsdl:message name="getJpgImageResponse">
+   <wsdl:message name="getXmlTextResponse">
 
       <wsdl:part name="return" type="apachesoap:DataHandler"/>
 
@@ -45,35 +45,35 @@
 
    <wsdl:portType name="DataHandlerRpcLit">
 
-      <wsdl:operation name="getJpgImage">
+      <wsdl:operation name="getPlainText">
 
-         <wsdl:input message="impl:getJpgImageRequest" name="getJpgImageRequest"/>
+         <wsdl:input message="impl:getPlainTextRequest" name="getPlainTextRequest"/>
 
-         <wsdl:output message="impl:getJpgImageResponse" name="getJpgImageResponse"/>
+         <wsdl:output message="impl:getPlainTextResponse" name="getPlainTextResponse"/>
 
       </wsdl:operation>
 
-      <wsdl:operation name="getGifImage">
+      <wsdl:operation name="getXmlText">
 
-         <wsdl:input message="impl:getGifImageRequest" name="getGifImageRequest"/>
+         <wsdl:input message="impl:getXmlTextRequest" name="getXmlTextRequest"/>
 
-         <wsdl:output message="impl:getGifImageResponse" name="getGifImageResponse"/>
+         <wsdl:output message="impl:getXmlTextResponse" name="getXmlTextResponse"/>
 
       </wsdl:operation>
 
-      <wsdl:operation name="getPlainText">
+      <wsdl:operation name="getJpgImage">
 
-         <wsdl:input message="impl:getPlainTextRequest" name="getPlainTextRequest"/>
+         <wsdl:input message="impl:getJpgImageRequest" name="getJpgImageRequest"/>
 
-         <wsdl:output message="impl:getPlainTextResponse" name="getPlainTextResponse"/>
+         <wsdl:output message="impl:getJpgImageResponse" name="getJpgImageResponse"/>
 
       </wsdl:operation>
 
-      <wsdl:operation name="getXmlText">
+      <wsdl:operation name="getGifImage">
 
-         <wsdl:input message="impl:getXmlTextRequest" name="getXmlTextRequest"/>
+         <wsdl:input message="impl:getGifImageRequest" name="getGifImageRequest"/>
 
-         <wsdl:output message="impl:getXmlTextResponse" name="getXmlTextResponse"/>
+         <wsdl:output message="impl:getGifImageResponse" name="getGifImageResponse"/>
 
       </wsdl:operation>
 
@@ -83,17 +83,17 @@
 
       <wsdlsoap:binding style="rpc" transport="http://schemas.xmlsoap.org/soap/http"/>
 
-      <wsdl:operation name="getJpgImage">
+      <wsdl:operation name="getPlainText">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getJpgImageRequest">
+         <wsdl:input name="getPlainTextRequest">
 
             <wsdlsoap:body namespace="http://datahandler.attachments" use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getJpgImageResponse">
+         <wsdl:output name="getPlainTextResponse">
 
             <wsdlsoap:body namespace="http://datahandler.attachments" use="literal"/>
 
@@ -101,17 +101,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="getGifImage">
+      <wsdl:operation name="getXmlText">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getGifImageRequest">
+         <wsdl:input name="getXmlTextRequest">
 
             <wsdlsoap:body namespace="http://datahandler.attachments" use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getGifImageResponse">
+         <wsdl:output name="getXmlTextResponse">
 
             <wsdlsoap:body namespace="http://datahandler.attachments" use="literal"/>
 
@@ -119,17 +119,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="getPlainText">
+      <wsdl:operation name="getJpgImage">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getPlainTextRequest">
+         <wsdl:input name="getJpgImageRequest">
 
             <wsdlsoap:body namespace="http://datahandler.attachments" use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getPlainTextResponse">
+         <wsdl:output name="getJpgImageResponse">
 
             <wsdlsoap:body namespace="http://datahandler.attachments" use="literal"/>
 
@@ -137,17 +137,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="getXmlText">
+      <wsdl:operation name="getGifImage">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getXmlTextRequest">
+         <wsdl:input name="getGifImageRequest">
 
             <wsdlsoap:body namespace="http://datahandler.attachments" use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getXmlTextResponse">
+         <wsdl:output name="getGifImageResponse">
 
             <wsdlsoap:body namespace="http://datahandler.attachments" use="literal"/>
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartDocLitWrapped.wsdl
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartDocLitWrapped.wsdl?rev=386715&r1=386714&r2=386715&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartDocLitWrapped.wsdl (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartDocLitWrapped.wsdl Fri Mar 17 13:18:24 2006
@@ -5,16 +5,6 @@
  <wsdl:types>
   <schema elementFormDefault="qualified" targetNamespace="http://mimemultipart.attachments" xmlns="http://www.w3.org/2001/XMLSchema">
    <import namespace="http://xml.apache.org/xml-soap"/>
-   <element name="getImages">
-    <complexType/>
-   </element>
-   <element name="getImagesResponse">
-    <complexType>
-     <sequence>
-      <element name="return" type="apachesoap:Multipart"/>
-     </sequence>
-    </complexType>
-   </element>
    <element name="echoPlainText">
     <complexType>
      <sequence>
@@ -43,6 +33,16 @@
      </sequence>
     </complexType>
    </element>
+   <element name="getImages">
+    <complexType/>
+   </element>
+   <element name="getImagesResponse">
+    <complexType>
+     <sequence>
+      <element name="return" type="apachesoap:Multipart"/>
+     </sequence>
+    </complexType>
+   </element>
   </schema>
  </wsdl:types>
 
@@ -84,14 +84,6 @@
 
    <wsdl:portType name="MimeMultipartDocLitWrapped">
 
-      <wsdl:operation name="getImages">
-
-         <wsdl:input message="impl:getImagesRequest" name="getImagesRequest"/>
-
-         <wsdl:output message="impl:getImagesResponse" name="getImagesResponse"/>
-
-      </wsdl:operation>
-
       <wsdl:operation name="echoPlainText">
 
          <wsdl:input message="impl:echoPlainTextRequest" name="echoPlainTextRequest"/>
@@ -108,23 +100,31 @@
 
       </wsdl:operation>
 
+      <wsdl:operation name="getImages">
+
+         <wsdl:input message="impl:getImagesRequest" name="getImagesRequest"/>
+
+         <wsdl:output message="impl:getImagesResponse" name="getImagesResponse"/>
+
+      </wsdl:operation>
+
    </wsdl:portType>
 
    <wsdl:binding name="MimeMultipartDocLitWrappedSoapBinding" type="impl:MimeMultipartDocLitWrapped">
 
       <wsdlsoap:binding style="document" transport="http://schemas.xmlsoap.org/soap/http"/>
 
-      <wsdl:operation name="getImages">
+      <wsdl:operation name="echoPlainText">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getImagesRequest">
+         <wsdl:input name="echoPlainTextRequest">
 
             <wsdlsoap:body use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getImagesResponse">
+         <wsdl:output name="echoPlainTextResponse">
 
             <wsdlsoap:body use="literal"/>
 
@@ -132,17 +132,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="echoPlainText">
+      <wsdl:operation name="echoXmlText">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="echoPlainTextRequest">
+         <wsdl:input name="echoXmlTextRequest">
 
             <wsdlsoap:body use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="echoPlainTextResponse">
+         <wsdl:output name="echoXmlTextResponse">
 
             <wsdlsoap:body use="literal"/>
 
@@ -150,17 +150,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="echoXmlText">
+      <wsdl:operation name="getImages">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="echoXmlTextRequest">
+         <wsdl:input name="getImagesRequest">
 
             <wsdlsoap:body use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="echoXmlTextResponse">
+         <wsdl:output name="getImagesResponse">
 
             <wsdlsoap:body use="literal"/>
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartRpcEnc.wsdl
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartRpcEnc.wsdl?rev=386715&r1=386714&r2=386715&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartRpcEnc.wsdl (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartRpcEnc.wsdl Fri Mar 17 13:18:24 2006
@@ -39,14 +39,6 @@
 
    <wsdl:portType name="MimeMultipartRpcEnc">
 
-      <wsdl:operation name="getImages">
-
-         <wsdl:input message="impl:getImagesRequest" name="getImagesRequest"/>
-
-         <wsdl:output message="impl:getImagesResponse" name="getImagesResponse"/>
-
-      </wsdl:operation>
-
       <wsdl:operation name="echoPlainText" parameterOrder="pt">
 
          <wsdl:input message="impl:echoPlainTextRequest" name="echoPlainTextRequest"/>
@@ -63,23 +55,31 @@
 
       </wsdl:operation>
 
+      <wsdl:operation name="getImages">
+
+         <wsdl:input message="impl:getImagesRequest" name="getImagesRequest"/>
+
+         <wsdl:output message="impl:getImagesResponse" name="getImagesResponse"/>
+
+      </wsdl:operation>
+
    </wsdl:portType>
 
    <wsdl:binding name="MimeMultipartRpcEncSoapBinding" type="impl:MimeMultipartRpcEnc">
 
       <wsdlsoap:binding style="rpc" transport="http://schemas.xmlsoap.org/soap/http"/>
 
-      <wsdl:operation name="getImages">
+      <wsdl:operation name="echoPlainText">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getImagesRequest">
+         <wsdl:input name="echoPlainTextRequest">
 
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://mimemultipart.attachments" use="encoded"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getImagesResponse">
+         <wsdl:output name="echoPlainTextResponse">
 
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://mimemultipart.attachments" use="encoded"/>
 
@@ -87,17 +87,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="echoPlainText">
+      <wsdl:operation name="echoXmlText">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="echoPlainTextRequest">
+         <wsdl:input name="echoXmlTextRequest">
 
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://mimemultipart.attachments" use="encoded"/>
 
          </wsdl:input>
 
-         <wsdl:output name="echoPlainTextResponse">
+         <wsdl:output name="echoXmlTextResponse">
 
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://mimemultipart.attachments" use="encoded"/>
 
@@ -105,17 +105,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="echoXmlText">
+      <wsdl:operation name="getImages">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="echoXmlTextRequest">
+         <wsdl:input name="getImagesRequest">
 
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://mimemultipart.attachments" use="encoded"/>
 
          </wsdl:input>
 
-         <wsdl:output name="echoXmlTextResponse">
+         <wsdl:output name="getImagesResponse">
 
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://mimemultipart.attachments" use="encoded"/>
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartRpcLit.wsdl
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartRpcLit.wsdl?rev=386715&r1=386714&r2=386715&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartRpcLit.wsdl (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/wsdl/schematypes/MimeMultipartRpcLit.wsdl Fri Mar 17 13:18:24 2006
@@ -39,14 +39,6 @@
 
    <wsdl:portType name="MimeMultipartRpcLit">
 
-      <wsdl:operation name="getImages">
-
-         <wsdl:input message="impl:getImagesRequest" name="getImagesRequest"/>
-
-         <wsdl:output message="impl:getImagesResponse" name="getImagesResponse"/>
-
-      </wsdl:operation>
-
       <wsdl:operation name="echoPlainText" parameterOrder="pt">
 
          <wsdl:input message="impl:echoPlainTextRequest" name="echoPlainTextRequest"/>
@@ -63,23 +55,31 @@
 
       </wsdl:operation>
 
+      <wsdl:operation name="getImages">
+
+         <wsdl:input message="impl:getImagesRequest" name="getImagesRequest"/>
+
+         <wsdl:output message="impl:getImagesResponse" name="getImagesResponse"/>
+
+      </wsdl:operation>
+
    </wsdl:portType>
 
    <wsdl:binding name="MimeMultipartRpcLitSoapBinding" type="impl:MimeMultipartRpcLit">
 
       <wsdlsoap:binding style="rpc" transport="http://schemas.xmlsoap.org/soap/http"/>
 
-      <wsdl:operation name="getImages">
+      <wsdl:operation name="echoPlainText">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="getImagesRequest">
+         <wsdl:input name="echoPlainTextRequest">
 
             <wsdlsoap:body namespace="http://mimemultipart.attachments" use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="getImagesResponse">
+         <wsdl:output name="echoPlainTextResponse">
 
             <wsdlsoap:body namespace="http://mimemultipart.attachments" use="literal"/>
 
@@ -87,17 +87,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="echoPlainText">
+      <wsdl:operation name="echoXmlText">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="echoPlainTextRequest">
+         <wsdl:input name="echoXmlTextRequest">
 
             <wsdlsoap:body namespace="http://mimemultipart.attachments" use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="echoPlainTextResponse">
+         <wsdl:output name="echoXmlTextResponse">
 
             <wsdlsoap:body namespace="http://mimemultipart.attachments" use="literal"/>
 
@@ -105,17 +105,17 @@
 
       </wsdl:operation>
 
-      <wsdl:operation name="echoXmlText">
+      <wsdl:operation name="getImages">
 
          <wsdlsoap:operation soapAction=""/>
 
-         <wsdl:input name="echoXmlTextRequest">
+         <wsdl:input name="getImagesRequest">
 
             <wsdlsoap:body namespace="http://mimemultipart.attachments" use="literal"/>
 
          </wsdl:input>
 
-         <wsdl:output name="echoXmlTextResponse">
+         <wsdl:output name="getImagesResponse">
 
             <wsdlsoap:body namespace="http://mimemultipart.attachments" use="literal"/>
--- beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/GeneratorUtils.java (original)
+++ beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/GeneratorUtils.java Fri Mar 17 13:18:24 2006
@@ -16,7 +16,6 @@
 package org.apache.beehive.controls.system.webservice.generator;
 
 import java.io.File;
-import java.io.FileInputStream;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -289,12 +288,12 @@
     /**
      * Copy src file to dest file.
      *
      * @param src  Source file.
      * @param dest Destination file.
      * @throws IOException On error.
      */
-    static void copyFile(File src, File dest) throws IOException {
-        InputStream is = new FileInputStream(src);
+    static void copyFile(URL src, File dest) throws IOException {
+        InputStream is = src.openStream();
         OutputStream os = new FileOutputStream(dest);
 
         byte[] buf = new byte[1024];
@@ -304,6 +303,26 @@
         }
         is.close();
         os.close();
+    }
+
+    /**
+     * Generate a name for a WSDL file based on a URL which specifies the location
+     * of the WSDL.
+     *
+     * @param wsdlURL URL to WSDL.
+     * @return File name for the WSDL.
+     */
+    static String genWsdlFileNameFromURL(URL wsdlURL) {
+        String urlPath = wsdlURL.getPath();
+        int idx = urlPath.lastIndexOf('/') + 1;
+        int dotIdx = urlPath.lastIndexOf('.');
+
+        if (dotIdx > idx) {
+            return urlPath.substring(idx, dotIdx) + ".wsdl";
+        }
+        else {
+            return urlPath.substring(idx) + ".wsdl";
+        }
     }
 
     /**
@@ -289,12 +288,12 @@
      * Copy src file to dest file.
      *
-     * @param src  Source file.
+     * @param src  URL of the source file.
      * @param dest Destination file.
      * @throws IOException On error.

Modified: beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/WebServiceControlGenerator.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/generator/WebServiceControlGenerator.java?rev=386715&r1=386714&r2=386715&view=diff
==============================================================================